@@ -10,7 +10,7 @@
 
 #include "kcalprefs.h"
 #include "utils.h"
-#include <Akonadi/Calendar/IncidenceChanger>
+#include <Akonadi/IncidenceChanger>
 
 #include <KCalendarCore/FileStorage>
 #include <KCalendarCore/ICalFormat>
@@ -57,9 +57,7 @@ EventArchiver::EventArchiver(QObject *parent)
 {
 }
 
-EventArchiver::~EventArchiver()
-{
-}
+EventArchiver::~EventArchiver() = default;
 
 void EventArchiver::runOnce(const Akonadi::ETMCalendar::Ptr &calendar, Akonadi::IncidenceChanger *changer, QDate limitDate, QWidget *widget)
 {
@@ -306,7 +304,7 @@ bool EventArchiver::isSubTreeComplete(const Akonadi::ETMCalendar::Ptr &calendar,
         return false;
     }
 
-    // This QList is only to prevent infinit recursion
+    // This QList is only to prevent infinite recursion
     if (checkedUids.contains(todo->uid())) {
         // Probably will never happen, calendar.cpp checks for this
         qCWarning(CALENDARSUPPORT_LOG) << "To-do hierarchy loop detected!";
@@ -314,8 +312,8 @@ bool EventArchiver::isSubTreeComplete(const Akonadi::ETMCalendar::Ptr &calendar,
     }
 
     checkedUids.append(todo->uid());
-    const KCalendarCore::Incidence::List childs = calendar->childIncidences(todo->uid());
-    for (const KCalendarCore::Incidence::Ptr &incidence : childs) {
+    const KCalendarCore::Incidence::List children = calendar->childIncidences(todo->uid());
+    for (const KCalendarCore::Incidence::Ptr &incidence : children) {
         const Todo::Ptr t = incidence.dynamicCast<KCalendarCore::Todo>();
         if (t && !isSubTreeComplete(calendar, t, limitDate, checkedUids)) {
             return false;
