@@ -3,7 +3,7 @@
   SPDX-FileCopyrightText: 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
   SPDX-FileCopyrightText: 2003 Cornelius Schumacher <schumacher@kde.org>
   SPDX-FileCopyrightText: 2008 Ron Goodheart <rong.dev@gmail.com>
-  SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2010-2022 Laurent Montel <montel@kde.org>
   SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
@@ -15,7 +15,7 @@
 
 #include <cmath>
 
-#include <Item>
+#include <Akonadi/Item>
 
 #include <KCalendarCore/Visitor>
 
@@ -25,7 +25,6 @@
 #include <KConfigGroup>
 
 #include <QPainter>
-#include <QPrinter>
 
 using namespace CalendarSupport;
 
@@ -38,9 +37,7 @@ CalPrintIncidence::CalPrintIncidence()
 {
 }
 
-CalPrintIncidence::~CalPrintIncidence()
-{
-}
+CalPrintIncidence::~CalPrintIncidence() = default;
 
 QWidget *CalPrintIncidence::createConfigWidget(QWidget *w)
 {
@@ -104,9 +101,7 @@ void CalPrintIncidence::doSaveConfig()
 class TimePrintStringsVisitor : public KCalendarCore::Visitor
 {
 public:
-    TimePrintStringsVisitor()
-    {
-    }
+    TimePrintStringsVisitor() = default;
 
     bool act(KCalendarCore::IncidenceBase::Ptr incidence)
     {
@@ -209,7 +204,8 @@ void CalPrintIncidence::print(QPainter &p, int width, int height)
     QFont captionFont(QStringLiteral("sans-serif"), 11, QFont::Bold);
     p.setFont(textFont);
     int lineHeight = p.fontMetrics().lineSpacing();
-    QString cap, txt;
+    QString cap;
+    QString txt;
 
     KCalendarCore::Incidence::List::ConstIterator it;
     for (it = mSelectedIncidences.constBegin(); it != mSelectedIncidences.constEnd(); ++it) {
@@ -643,9 +639,7 @@ CalPrintTimetable::CalPrintTimetable()
 {
 }
 
-CalPrintTimetable::~CalPrintTimetable()
-{
-}
+CalPrintTimetable::~CalPrintTimetable() = default;
 
 void CalPrintTimetable::doLoadConfig()
 {
@@ -769,7 +763,6 @@ void CalPrintTimetable::drawTimeTable(QPainter &p,
         curDate = curDate.addDays(1);
     }
 
-    QFont oldFont(p.font());
     p.setFont(QFont(QStringLiteral("sans-serif"), 11, QFont::Normal));
     const int lineSpacing = p.fontMetrics().lineSpacing();
 
@@ -786,7 +779,7 @@ void CalPrintTimetable::drawTimeTable(QPainter &p,
     if (maxAllDayEvents > 0) {
         // Draw the side bar for all-day events.
         const auto alldayLabel =  i18nc("label for timetable all-day boxes", "All day");
-        QFont oldFont(p.font());
+        const QFont oldFont(p.font());
         p.setFont(QFont(QStringLiteral("sans-serif"), 9, QFont::Normal));
         const auto labelHeight = p.fontMetrics().horizontalAdvance(alldayLabel) + 2*padding();
         alldayHeight = std::max(maxAllDayEvents*lineSpacing + 2*padding(), labelHeight);
@@ -852,9 +845,7 @@ CalPrintDay::CalPrintDay()
 {
 }
 
-CalPrintDay::~CalPrintDay()
-{
-}
+CalPrintDay::~CalPrintDay() = default;
 
 QWidget *CalPrintDay::createConfigWidget(QWidget *w)
 {
@@ -1062,9 +1053,7 @@ CalPrintWeek::CalPrintWeek()
 {
 }
 
-CalPrintWeek::~CalPrintWeek()
-{
-}
+CalPrintWeek::~CalPrintWeek() = default;
 
 QWidget *CalPrintWeek::createConfigWidget(QWidget *w)
 {
@@ -1220,7 +1209,9 @@ void CalPrintWeek::drawWeek(QPainter &p,
 
 void CalPrintWeek::print(QPainter &p, int width, int height)
 {
-    QDate curWeek, fromWeek, toWeek;
+    QDate curWeek;
+    QDate fromWeek;
+    QDate toWeek;
 
     // correct begin and end to first and last day of week
     int weekdayCol = weekdayColumn(mFromDate.dayOfWeek());
@@ -1231,7 +1222,9 @@ void CalPrintWeek::print(QPainter &p, int width, int height)
     curWeek = fromWeek.addDays(6);
     auto local = QLocale::system();
 
-    QString line1, line2, title;
+    QString line1;
+    QString line2;
+    QString title;
     QRect headerBox(0, 0, width, headerHeight());
     QRect footerBox(0, height - footerHeight(), width, footerHeight());
     height -= footerHeight();
@@ -1330,9 +1323,7 @@ CalPrintMonth::CalPrintMonth()
 {
 }
 
-CalPrintMonth::~CalPrintMonth()
-{
-}
+CalPrintMonth::~CalPrintMonth() = default;
 
 QWidget *CalPrintMonth::createConfigWidget(QWidget *w)
 {
@@ -1438,7 +1429,9 @@ void CalPrintMonth::setDateRange(const QDate &from, const QDate &to)
 
 void CalPrintMonth::print(QPainter &p, int width, int height)
 {
-    QDate curMonth, fromMonth, toMonth;
+    QDate curMonth;
+    QDate fromMonth;
+    QDate toMonth;
 
     fromMonth = mFromDate.addDays(-(mFromDate.day() - 1));
     toMonth = mToDate.addDays(mToDate.daysInMonth() - mToDate.day());
@@ -1493,9 +1486,7 @@ CalPrintTodos::CalPrintTodos()
     mTodoSortDirection = TodoDirectionUnset;
 }
 
-CalPrintTodos::~CalPrintTodos()
-{
-}
+CalPrintTodos::~CalPrintTodos() = default;
 
 QWidget *CalPrintTodos::createConfigWidget(QWidget *w)
 {
