@@ -30,10 +30,10 @@ using namespace CalendarSupport;
 
 CalPrinter::CalPrinter(QWidget *parent, const Akonadi::ETMCalendar::Ptr &calendar, bool uniqItem)
     : QObject(parent)
+    , mParent(parent)
+    , mConfig(new KConfig(QStringLiteral("calendar_printing.rc"), KConfig::SimpleConfig))
     , mUniqItem(uniqItem)
 {
-    mParent = parent;
-    mConfig = new KConfig(QStringLiteral("calendar_printing.rc"), KConfig::SimpleConfig);
 
     init(calendar);
 }
@@ -74,7 +74,7 @@ void CalPrinter::init(const Akonadi::ETMCalendar::Ptr &calendar)
 
 void CalPrinter::setDateRange(QDate fd, QDate td)
 {
-    for (const auto plugin : mPrintPlugins) {
+    for (const auto plugin : std::as_const(mPrintPlugins)) {
         plugin->setDateRange(fd, td);
     }
 }
@@ -202,7 +202,7 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
     splitterRightLayout->addWidget(mOrientationSelection, 1, 1);
 
     // signals and slots connections
-    connect(mTypeGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &CalPrintDialog::setPrintType);
+    connect(mTypeGroup, &QButtonGroup::buttonClicked, this, &CalPrintDialog::setPrintType);
     orientationLabel->setBuddy(mOrientationSelection);
 
     // First insert the config widgets into the widget stack. This possibly assigns
@@ -245,9 +245,7 @@ CalPrintDialog::CalPrintDialog(int initialPrintType, const PrintPlugin::List &pl
     resize(minimumSizeHint());
 }
 
-CalPrintDialog::~CalPrintDialog()
-{
-}
+CalPrintDialog::~CalPrintDialog() = default;
 
 void CalPrintDialog::setPreview(bool preview)
 {
