@@ -12,7 +12,7 @@
 #include "kcalprefs.h"
 #include "utils.h"
 
-#include <Item>
+#include <Akonadi/Item>
 
 #include "calendarsupport_debug.h"
 #include <KConfig>
@@ -73,22 +73,22 @@ public:
     {
     }
 
-    KCalendarCore::Event::Ptr event() const
+    Q_REQUIRED_RESULT KCalendarCore::Event::Ptr event() const
     {
         return mEvent;
     }
 
-    QString label() const override
+    Q_REQUIRED_RESULT QString label() const override
     {
         return mEvent->summary();
     }
 
-    QDateTime start() const
+    Q_REQUIRED_RESULT QDateTime start() const
     {
         return mStart;
     }
 
-    QDateTime end() const
+    Q_REQUIRED_RESULT QDateTime end() const
     {
         return mEnd;
     }
@@ -122,9 +122,7 @@ CalPrintPluginBase::CalPrintPluginBase()
 {
 }
 
-CalPrintPluginBase::~CalPrintPluginBase()
-{
-}
+CalPrintPluginBase::~CalPrintPluginBase() = default;
 
 QWidget *CalPrintPluginBase::createConfigWidget(QWidget *w)
 {
@@ -294,7 +292,7 @@ QColor CalPrintPluginBase::categoryBgColor(const KCalendarCore::Incidence::Ptr &
         }
         return backColor;
     } else {
-        return QColor();
+        return {};
     }
 }
 
@@ -308,7 +306,7 @@ KCalendarCore::Event::Ptr CalPrintPluginBase::holidayEvent(QDate date) const
 {
     QString hstring(holidayString(date));
     if (hstring.isEmpty()) {
-        return KCalendarCore::Event::Ptr();
+        return {};
     }
 
     KCalendarCore::Event::Ptr holiday(new KCalendarCore::Event);
@@ -775,7 +773,8 @@ void CalPrintPluginBase::drawAgendaDayBox(QPainter &p,
                                           bool excludeTime,
                                           const QList<QDate> &workDays)
 {
-    QTime myFromTime, myToTime;
+    QTime myFromTime;
+    QTime myToTime;
     if (fromTime.isValid()) {
         myFromTime = fromTime;
     } else {
@@ -981,7 +980,8 @@ void CalPrintPluginBase::drawDayBox(QPainter &p,
     QString dayNumStr;
     const auto local = QLocale::system();
 
-    QTime myFromTime, myToTime;
+    QTime myFromTime;
+    QTime myToTime;
     if (fromTime.isValid()) {
         myFromTime = fromTime;
     } else {
@@ -1282,7 +1282,6 @@ void CalPrintPluginBase::drawMonth(QPainter &p,
         maxdays = daysinmonth;
     }
 
-    int d;
     float dayheight = float(daysBox.height()) / float(maxdays);
 
     QColor holidayColor(240, 240, 240);
@@ -1307,7 +1306,7 @@ void CalPrintPluginBase::drawMonth(QPainter &p,
         workDays = CalendarSupport::workDays(startDate, endDate);
     }
 
-    for (d = 0; d < daysinmonth; ++d) {
+    for (int d = 0; d < daysinmonth; ++d) {
         QDate day(dt.year(), dt.month(), d + 1);
         QRect dayBox(daysBox.left() /*+rand()%50*/, daysBox.top() + qRound(dayheight * d), daysBox.width() /*-rand()%50*/, 0);
         // FIXME: When using a border width of 0 for event boxes,
@@ -1493,7 +1492,8 @@ void CalPrintPluginBase::drawMonthTable(QPainter &p,
 
     // Precalculate the grid...
     // rows is at most 6, so using 8 entries in the array is fine, too!
-    int coledges[8], rowedges[8];
+    int coledges[8];
+    int rowedges[8];
     for (int i = 0; i <= 7; ++i) {
         rowedges[i] = int(box.top() + yoffset + i * cellHeight);
         coledges[i] = int(box.left() + xoffset + i * cellWidth);
